==> nextcloud-13.0.1.tgz: nextcloud/settings/l10n/lb.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Falscht Passwuert",
    "Saved" : "Gespäichert",
    "Authentication error" : "Authentifikatioun's Fehler",
    "Email saved" : "E-mail gespäichert",
    "Not saved" : "Nët gespäichert",
    "Email sent" : "Email geschéckt",
    "All" : "All",
    "The app will be downloaded from the app store" : "D'App gett aus dem App Store erofgelueden",
    "Disable" : "Ofschalten",
    "Enable" : "Aschalten",
    "Error while enabling app" : "Fehler beim Aktivéieren vun der App",
    "Delete" : "Läschen",
    "Groups" : "Gruppen",
    "undo" : "réckgängeg man",
    "never" : "ni",
    "None" : "Keng",
    "Login" : "Login",
    "Open documentation" : "Dokumentatioun opmaachen",
    "Authentication required" : "Authentifizéierung néideg",
    "Server address" : "Server Adress",
    "Port" : "Port",
    "Sharing" : "Gedeelt",
    "Allow apps to use the Share API" : "Erlab Apps d'Share API ze benotzen",
    "days" : "Deeg",
    "Allow resharing" : "Resharing erlaben",
    "Cancel" : "Ofbriechen",
    "Email" : "Email",
    "Your email address" : "Deng Email Adress",
    "Language" : "Sprooch",
    "Help translate" : "Hëllef iwwersetzen",
    "Password" : "Passwuert",
    "Current password" : "Momentan 't Passwuert",
    "New password" : "Neit Passwuert",
    "Change password" : "Passwuert änneren",
    "Username" : "Benotzernumm",
    "Other" : "Aner",
    "Quota" : "Quota",
    "E-Mail" : "E-Mail",
    "Create" : "Erstellen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.1.tgz: nextcloud/settings/l10n/lb.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Falscht Passwuert",
    "Saved" : "Gespäichert",
    "Authentication error" : "Authentifikatioun's Fehler",
    "Not saved" : "Nët gespäichert",
    "Email sent" : "Email geschéckt",
    "Delete" : "Läschen",
    "Groups" : "Gruppen",
    "Enable" : "Aschalten",
    "The app will be downloaded from the app store" : "D'App gett aus dem App Store erofgelueden",
    "Email" : "Email",
    "Language" : "Sprooch",
    "None" : "Keng",
    "Login" : "Login",
    "Open documentation" : "Dokumentatioun opmaachen",
    "Authentication required" : "Authentifizéierung néideg",
    "Server address" : "Server Adress",
    "Port" : "Port",
    "Sharing" : "Gedeelt",
    "Allow apps to use the Share API" : "Erlab Apps d'Share API ze benotzen",
    "days" : "Deeg",
    "Allow resharing" : "Resharing erlaben",
    "Cancel" : "Ofbriechen",
    "Your email address" : "Deng Email Adress",
    "Help translate" : "Hëllef iwwersetzen",
    "Password" : "Passwuert",
    "Current password" : "Momentan 't Passwuert",
    "New password" : "Neit Passwuert",
    "Change password" : "Passwuert änneren",
    "Username" : "Benotzernumm",
    "Email saved" : "E-mail gespäichert",
    "All" : "All",
    "Disable" : "Ofschalten",
    "Error while enabling app" : "Fehler beim Aktivéieren vun der App",
    "undo" : "réckgängeg man",
    "never" : "ni",
    "E-Mail" : "E-Mail",
    "Create" : "Erstellen",
    "Other" : "Aner",
    "Quota" : "Quota"
},
"nplurals=2; plural=(n != 1);");
